#!/bin/bash

# Based on Start-Script

#NetBSD workaround
os=$(uname)
if [ "$os" = "NetBSD" ]; then
	ulimit -d 656020
fi

MSG0="Loading bikeXperience:"
MSG1="Starting bikeXperience..."
MSG2="Java exec found in "
MSG3="OOPS, your java version is too old "
MSG4="You need to upgrade to JRE 1.4.x or newer from http://java.sun.com"
MSG5="Suitable java version found "
MSG6="Configuring environment..."
MSG7="OOPS, you don't seem to have a valid JRE "
MSG8="OOPS, unable to locate java exec in "
MSG9=" hierarchy"
MSG10="Java exec not found in PATH, starting auto-search..."
MSG11="Java exec found in PATH. Verifying..."

JAVA_BIN_DIR=""
#BXP_DIR="/home/user/BikeXperience"

look_for_java()
{
  JAVADIR=/usr/java
  IFS=$'\n'
  potential_java_dirs=(`ls -1 "$JAVADIR" | sort | tac`)
  IFS=
  for D in "${potential_java_dirs[@]}"; do
    if [[ -d "$JAVADIR/$D" && -x "$JAVADIR/$D/bin/java" ]]; then
      JAVA_BIN_DIR="$JAVADIR/$D/bin/"
      echo $MSG2 $JAVA_BIN_DIR
      if check_version ; then
        return 0
      else
        return 1
      fi
    fi
  done
  echo $MSG8 "${JAVADIR}/" $MSG9 ; echo $MSG4
  return 1
}

check_version()
{
  JAVA_HEADER=`${JAVA_BIN_DIR}java -version 2>&1 | head -n 1`
  JAVA_IMPL=`echo ${JAVA_HEADER} | cut -f1 -d' '`
  if [ "$JAVA_IMPL" = "java" ] ; then
    VERSION=`echo ${JAVA_HEADER} | sed "s/java version \"\(.*\)\"/\1/"`
    if echo $VERSION | grep "^1.[0-3]" ; then
      echo $MSG3 "[${JAVA_BIN_DIR}java = ${VERSION}]" ; echo $MSG4
      return 1
    else
      echo $MSG5 "[${JAVA_BIN_DIR}java = ${VERSION}]" ; echo $MSG6
      return 0	      
    fi
  else
    echo $MSG7 "[${JAVA_BIN_DIR}java = ${JAVA_IMPL}]" ; echo $MSG4
    return 1
  fi
}

echo $MSG1

# locate and test the java executable
if [ "$JAVA_BIN_DIR" == "" ]; then
  if ! command -v java &>/dev/null; then
    echo $MSG10
    if ! look_for_java ; then
		echo "Please push any key for closing."
		read -n 1
	    exit 1
    fi
  else
    echo $MSG11
    if ! check_version ; then
      if ! look_for_java ; then
		echo "Please push any key for closing."
		read -n 1
        exit 1
      fi
    fi
  fi
fi


# get the app dir if not already defined
if [ -z "$BXP_DIR" ]; then
    if [ -L $0 ] 
    then
        SL= `file $0 | sed -e 's/.*to..\(.*\)./\1/'`
        BXP_DIR=`dirname $SL`
    else
        BXP_DIR=`dirname $0`
    fi
    
    BXP_DIR=`cd "$BXP_DIR"; pwd`
else
    if [ "$(echo ${BXP_DIR}/*.jar)" = "${BXP_DIR}/*.jar" ]; then
	echo "You seem to have set an invalid BXP_DIR, unable to continue!"
	exit 1
    elif ! (echo ${BXP_DIR}/*.jar | grep bikeXperience.jar >/dev/null 2>&1 ); then
	echo "Unable to locate bikeXperience.jar in $BXP_DIR, aborting!"
	echo "Please push any key for closing."
	read -n 1
	exit 1
    fi
fi

echo $MSG0

cd ${BXP_DIR}

#set library path
export LD_LIBRARY_PATH="$LD_LIBRAY_PATH:$BXP_DIR"

#set codepage for Ubuntu
etcissue=$(cat /etc/issue)
if echo "$etcissue" | grep -q "Ubuntu"
then
     echo "Set codepage for Ubuntu"
     export LC_ALL=de_DE.ISO-8859-15
fi

echo "${JAVA_BIN_DIR}java -jar bikeXperience.jar '$@'"
${JAVA_BIN_DIR}java -Xmn150M -Xms500M -Xmx500M -jar bikeXperience.jar "$@"
#${JAVA_BIN_DIR}java -Xms16m -Xmx128m -Djava.library.path="${BXP_DIR}" -jar bikeXperience.jar "$@"

echo "bikeXperience TERMINATED."
echo "Please push any key for closing."
read -n 1
